@@ -11,7 +11,7 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = @{$EXPORT_TAGS{all}};
 our @EXPORT = ();
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 require XSLoader;
 XSLoader::load('HTTP::Parser::XS', $VERSION);
@@ -74,13 +74,18 @@ given request is incomplete
 
 =back
 
+=head1 COPYRIGHT
+
+Copyright 2009- Kazuho Oku
+
 =head1 AUTHOR
 
-Kazuho Oku E<lt>kazuhooku@gmail.comE<gt>
+Kazuho Oku
 
 =head1 THANKS TO
 
 nothingmuch
+charsbar
 
 =head1 SEE ALSO
 
